contexttools.DynamicMark
========================

.. abjad-lineage:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark

.. autoclass:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.dynamic_name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark.__repr__
   :noindex:
